==> lucide_py-0.1.0-py3-none-any.whl: lucide/icons/qr_code.py <==
from .. import IconBase


class IconQrCode(IconBase):
    class_name = "lucide lucide-qr-code"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "rect": {
                "width": "5",
                "height": "5",
                "x": "3",
                "y": "3",
                "rx": "1"
            }
        },
        {
            "rect": {
                "width": "5",
                "height": "5",
                "x": "16",
                "y": "3",
                "rx": "1"
            }
        },
        {
            "rect": {
                "width": "5",
                "height": "5",
                "x": "3",
                "y": "16",
                "rx": "1"
            }
        },
        {
            "path": {
                "d": "M21 16h-3a2 2 0 0 0-2 2v3"
            }
        },
        {
            "path": {
                "d": "M21 21v.01"
            }
        },
        {
            "path": {
                "d": "M12 7v3a2 2 0 0 1-2 2H7"
            }
        },
        {
            "path": {
                "d": "M3 12h.01"
            }
        },
        {
            "path": {
                "d": "M12 3h.01"
            }
        },
        {
            "path": {
                "d": "M12 16v.01"
            }
        },
        {
            "path": {
                "d": "M16 12h1"
            }
        },
        {
            "path": {
                "d": "M21 12v.01"
            }
        },
        {
            "path": {
                "d": "M12 21v-1"
            }
        }
    ]
}

==> lucide_py-0.1.1-py3-none-any.whl: lucide/icons/qr_code.py <==
from .. import IconBase


class IconQrCode(IconBase):
    class_name = "lucide lucide-qr-code"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "view_box": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "rect": {
                "width": "5",
                "height": "5",
                "x": "3",
                "y": "3",
                "rx": "1"
            }
        },
        {
            "rect": {
                "width": "5",
                "height": "5",
                "x": "16",
                "y": "3",
                "rx": "1"
            }
        },
        {
            "rect": {
                "width": "5",
                "height": "5",
                "x": "3",
                "y": "16",
                "rx": "1"
            }
        },
        {
            "path": {
                "d": "M21 16h-3a2 2 0 0 0-2 2v3"
            }
        },
        {
            "path": {
                "d": "M21 21v.01"
            }
        },
        {
            "path": {
                "d": "M12 7v3a2 2 0 0 1-2 2H7"
            }
        },
        {
            "path": {
                "d": "M3 12h.01"
            }
        },
        {
            "path": {
                "d": "M12 3h.01"
            }
        },
        {
            "path": {
                "d": "M12 16v.01"
            }
        },
        {
            "path": {
                "d": "M16 12h1"
            }
        },
        {
            "path": {
                "d": "M21 12v.01"
            }
        },
        {
            "path": {
                "d": "M12 21v-1"
            }
        }
    ]
}
